package com.jiuqi.util;

import java.io.InputStream;
import java.io.ByteArrayInputStream;
import java.io.OutputStream;
import java.io.ByteArrayOutputStream;

public abstract class CustomIniFile implements IniFile
{
    public void writeInteger(final String section, final String ident, final Integer value) {
        this.writeString(section, ident, (value == null) ? "0" : value.toString());
    }
    
    public void writeint(final String section, final String ident, final int value) {
        this.writeString(section, ident, Integer.toString(value));
    }
    
    public void writeLong(final String section, final String ident, final Long value) {
        this.writeString(section, ident, (value == null) ? "0" : value.toString());
    }
    
    public void writelong(final String section, final String ident, final long value) {
        this.writeString(section, ident, Long.toString(value));
    }
    
    public void writeDouble(final String section, final String ident, final Double value) {
        this.writeString(section, ident, (value == null) ? "0" : value.toString());
    }
    
    public void writedouble(final String section, final String ident, final double value) {
        this.writeString(section, ident, Double.toString(value));
    }
    
    public void writeFloat(final String section, final String ident, final Float value) {
        this.writeString(section, ident, (value == null) ? "0" : value.toString());
    }
    
    public void writefloat(final String section, final String ident, final float value) {
        this.writeString(section, ident, Float.toString(value));
    }
    
    public void writeBoolean(final String section, final String ident, final Boolean value) {
        this.writeString(section, ident, (value == null) ? "0" : (value ? "1" : "0"));
    }
    
    public void writeboolean(final String section, final String ident, final boolean value) {
        this.writeBoolean(section, ident, new Boolean(value));
    }
    
    public void writeBytes(final String section, final String ident, final byte[] value) {
        final String s = (value == null) ? "" : new String(Base64.byteArrayToBase64(value));
        this.writeString(section, ident, s);
    }
    
    public Integer readInteger(final String section, final String ident, final Integer defvalue) {
        final String s = this.readString(section, ident, "");
        if (s == null || s.equals("")) {
            return defvalue;
        }
        return new Integer(s);
    }
    
    public int readint(final String section, final String ident, final int defvalue) {
        return this.readInteger(section, ident, new Integer(defvalue));
    }
    
    public Long readLong(final String section, final String ident, final Long defvalue) {
        final String s = this.readString(section, ident, "");
        if (s == null || s.equals("")) {
            return defvalue;
        }
        return new Long(s);
    }
    
    public long readlong(final String section, final String ident, final long defvalue) {
        return this.readLong(section, ident, new Long(defvalue));
    }
    
    public Double readDouble(final String section, final String ident, final Double defvalue) {
        final String s = this.readString(section, ident, "");
        if (s == null || s.equals("")) {
            return defvalue;
        }
        return new Double(s);
    }
    
    public double readdouble(final String section, final String ident, final double defvalue) {
        return this.readDouble(section, ident, new Double(defvalue));
    }
    
    public Boolean readBoolean(final String section, final String ident, final Boolean defvalue) {
        return new Boolean(this.readboolean(section, ident, defvalue != null && defvalue));
    }
    
    public boolean readboolean(final String section, final String ident, final boolean defvalue) {
        final String s = this.readString(section, ident, "");
        return (s == null || s.equals("")) ? defvalue : (!s.equals("0"));
    }
    
    public byte[] readBytes(final String section, final String ident, final byte[] defvalue) {
        final String s = this.readString(section, ident, "");
        return Base64.base64ToByteArray(s);
    }
    
    public byte[] getBytes() {
        final ByteArrayOutputStream stream = new ByteArrayOutputStream();
        this.saveToStream(stream);
        return stream.toByteArray();
    }
    
    public void setBytes(final byte[] value) {
        final ByteArrayInputStream stream = new ByteArrayInputStream(value);
        this.loadFromStream(stream);
    }
}
